@@ -1,26 +1,13 @@
-﻿# coding=UTF-8
-from __future__ import print_function, unicode_literals
-import six
-from six.moves import range, zip
-
-import calendar
-import functools
-import decimal
+﻿import decimal
 import json
 import math
-import time
 import sys
-import pytz
-import pytest
+import unittest
+from io import StringIO
+from srsly import ujson
 
-if six.PY2:
-    import unittest2 as unittest
-else:
-    import unittest
 
-from ... import ujson
-
-json_unicode = json.dumps if six.PY3 else functools.partial(json.dumps, encoding="utf-8")
+json_unicode = json.dumps
 
 
 class UltraJSONTests(unittest.TestCase):
@@ -33,13 +20,15 @@ class UltraJSONTests(unittest.TestCase):
     def test_encodeStringConversion(self):
         input = "A string \\ / \b \f \n \r \t </script> &"
         not_html_encoded = '"A string \\\\ \\/ \\b \\f \\n \\r \\t <\\/script> &"'
-        html_encoded = '"A string \\\\ \\/ \\b \\f \\n \\r \\t \\u003c\\/script\\u003e \\u0026"'
+        html_encoded = (
+            '"A string \\\\ \\/ \\b \\f \\n \\r \\t \\u003c\\/script\\u003e \\u0026"'
+        )
         not_slashes_escaped = '"A string \\\\ / \\b \\f \\n \\r \\t </script> &"'
 
         def helper(expected_output, **encode_kwargs):
             output = ujson.encode(input, **encode_kwargs)
             self.assertEqual(output, expected_output)
-            if encode_kwargs.get('escape_forward_slashes', True):
+            if encode_kwargs.get("escape_forward_slashes", True):
                 self.assertEqual(input, json.loads(output))
                 self.assertEqual(input, ujson.decode(output))
 
@@ -59,10 +48,13 @@ class UltraJSONTests(unittest.TestCase):
         helper(not_slashes_escaped, escape_forward_slashes=False)
 
     def testWriteEscapedString(self):
-        self.assertEqual('"\\u003cimg src=\'\\u0026amp;\'\\/\\u003e"', ujson.dumps("<img src='&amp;'/>", encode_html_chars=True))
+        self.assertEqual(
+            "\"\\u003cimg src='\\u0026amp;'\\/\\u003e\"",
+            ujson.dumps("<img src='&amp;'/>", encode_html_chars=True),
+        )
 
     def test_doubleLongIssue(self):
-        sut = {'a': -4342969734183514}
+        sut = {"a": -4342969734183514}
         encoded = json.dumps(sut)
         decoded = json.loads(encoded)
         self.assertEqual(sut, decoded)
@@ -71,7 +63,7 @@ class UltraJSONTests(unittest.TestCase):
         self.assertEqual(sut, decoded)
 
     def test_doubleLongDecimalIssue(self):
-        sut = {'a': -12345678901234.56789012}
+        sut = {"a": -12345678901234.56789012}
         encoded = json.dumps(sut)
         decoded = json.loads(encoded)
         self.assertEqual(sut, decoded)
@@ -80,21 +72,36 @@ class UltraJSONTests(unittest.TestCase):
         self.assertEqual(sut, decoded)
 
     def test_encodeDecodeLongDecimal(self):
-        sut = {'a': -528656961.4399388}
+        sut = {"a": -528656961.4399388}
         encoded = ujson.dumps(sut)
         ujson.decode(encoded)
 
     def test_decimalDecodeTest(self):
-        sut = {'a': 4.56}
+        sut = {"a": 4.56}
         encoded = ujson.encode(sut)
         decoded = ujson.decode(encoded)
-        self.assertAlmostEqual(sut[u'a'], decoded[u'a'])
+        self.assertAlmostEqual(sut[u"a"], decoded[u"a"])
 
     def test_encodeDictWithUnicodeKeys(self):
-        input = {"key1": "value1", "key1": "value1", "key1": "value1", "key1": "value1", "key1": "value1", "key1": "value1"}
+        input = {
+            "key1": "value1",
+            "key1": "value1",
+            "key1": "value1",
+            "key1": "value1",
+            "key1": "value1",
+            "key1": "value1",
+        }
         ujson.encode(input)
 
-        input = {"بن": "value1", "بن": "value1", "بن": "value1", "بن": "value1", "بن": "value1", "بن": "value1", "بن": "value1"}
+        input = {
+            "بن": "value1",
+            "بن": "value1",
+            "بن": "value1",
+            "بن": "value1",
+            "بن": "value1",
+            "بن": "value1",
+            "بن": "value1",
+        }
         ujson.encode(input)
 
     def test_encodeDoubleConversion(self):
@@ -119,14 +126,14 @@ class UltraJSONTests(unittest.TestCase):
         input = [[[[]]]] * 20
         output = ujson.encode(input)
         self.assertEqual(input, json.loads(output))
-        #self.assertEqual(output, json.dumps(input))
+        # self.assertEqual(output, json.dumps(input))
         self.assertEqual(input, ujson.decode(output))
 
     def test_encodeArrayOfDoubles(self):
         input = [31337.31337, 31337.31337, 31337.31337, 31337.31337] * 10
         output = ujson.encode(input)
         self.assertEqual(input, json.loads(output))
-        #self.assertEqual(output, json.dumps(input))
+        # self.assertEqual(output, json.dumps(input))
         self.assertEqual(input, ujson.decode(output))
 
     def test_encodeStringConversion2(self):
@@ -188,7 +195,7 @@ class UltraJSONTests(unittest.TestCase):
     # 16 bits) are represented as \UXXXXXXXX in python but should be encoded
     # as \uXXXX\uXXXX in json.
     def testEncodeUnicodeBMP(self):
-        s = '\U0001f42e\U0001f42e\U0001F42D\U0001F42D'  # 🐮🐮🐭🐭
+        s = "\U0001f42e\U0001f42e\U0001F42D\U0001F42D"  # 🐮🐮🐭🐭
         encoded = ujson.dumps(s)
         encoded_json = json.dumps(s)
 
@@ -202,11 +209,7 @@ class UltraJSONTests(unittest.TestCase):
         self.assertEqual(s, decoded)
 
         # ujson outputs an UTF-8 encoded str object
-        if six.PY3:
-            encoded = ujson.dumps(s, ensure_ascii=False)
-        else:
-            encoded = ujson.dumps(s, ensure_ascii=False).decode("utf-8")
-
+        encoded = ujson.dumps(s, ensure_ascii=False)
         # json outputs an unicode object
         encoded_json = json.dumps(s, ensure_ascii=False)
         self.assertEqual(len(encoded), len(s) + 2)  # original length + quotes
@@ -215,7 +218,7 @@ class UltraJSONTests(unittest.TestCase):
         self.assertEqual(s, decoded)
 
     def testEncodeSymbols(self):
-        s = '\u273f\u2661\u273f'  # ✿♡✿
+        s = "\u273f\u2661\u273f"  # ✿♡✿
         encoded = ujson.dumps(s)
         encoded_json = json.dumps(s)
         self.assertEqual(len(encoded), len(s) * 6 + 2)  # 6 characters + quotes
@@ -224,11 +227,7 @@ class UltraJSONTests(unittest.TestCase):
         self.assertEqual(s, decoded)
 
         # ujson outputs an UTF-8 encoded str object
-        if six.PY3:
-            encoded = ujson.dumps(s, ensure_ascii=False)
-        else:
-            encoded = ujson.dumps(s, ensure_ascii=False).decode("utf-8")
-
+        encoded = ujson.dumps(s, ensure_ascii=False)
         # json outputs an unicode object
         encoded_json = json.dumps(s, ensure_ascii=False)
         self.assertEqual(len(encoded), len(s) + 2)  # original length + quotes
@@ -305,15 +304,14 @@ class UltraJSONTests(unittest.TestCase):
 
     def test_encodeToUTF8(self):
         input = b"\xe6\x97\xa5\xd1\x88"
-        if six.PY3:
-            input = input.decode('utf-8')
+        input = input.decode("utf-8")
         enc = ujson.encode(input, ensure_ascii=False)
         dec = ujson.decode(enc)
         self.assertEqual(enc, json.dumps(input, ensure_ascii=False))
         self.assertEqual(dec, json.loads(enc))
 
     def test_decodeFromUnicode(self):
-        input = "{\"obj\": 31337}"
+        input = '{"obj": 31337}'
         dec1 = ujson.decode(input)
         dec2 = ujson.decode(str(input))
         self.assertEqual(dec1, dec2)
@@ -338,20 +336,20 @@ class UltraJSONTests(unittest.TestCase):
         self.assertRaises(OverflowError, ujson.encode, input)
 
     def test_encodeDoubleNan(self):
-        input = float('nan')
+        input = float("nan")
         self.assertRaises(OverflowError, ujson.encode, input)
 
     def test_encodeDoubleInf(self):
-        input = float('inf')
+        input = float("inf")
         self.assertRaises(OverflowError, ujson.encode, input)
 
     def test_encodeDoubleNegInf(self):
-        input = -float('inf')
+        input = -float("inf")
         self.assertRaises(OverflowError, ujson.encode, input)
 
-    @unittest.skipIf(sys.version_info < (2, 7), "No Ordered dict in < 2.7")
     def test_encodeOrderedDict(self):
         from collections import OrderedDict
+
         input = OrderedDict([(1, 1), (0, 0), (8, 8), (2, 2)])
         self.assertEqual('{"1":1,"0":0,"8":8,"2":2}', ujson.encode(input))
 
@@ -372,27 +370,31 @@ class UltraJSONTests(unittest.TestCase):
         self.assertRaises(ValueError, ujson.decode, input)
 
     def test_decodeArrayDepthTooBig(self):
-        input = '[' * (1024 * 1024)
+        input = "[" * (1024 * 1024)
         self.assertRaises(ValueError, ujson.decode, input)
 
     def test_decodeBrokenObjectEnd(self):
         input = "}"
         self.assertRaises(ValueError, ujson.decode, input)
 
+    def test_decodeObjectTrailingCommaFail(self):
+        input = '{"one":1,}'
+        self.assertRaises(ValueError, ujson.decode, input)
+
     def test_decodeObjectDepthTooBig(self):
-        input = '{' * (1024 * 1024)
+        input = "{" * (1024 * 1024)
         self.assertRaises(ValueError, ujson.decode, input)
 
     def test_decodeStringUnterminated(self):
-        input = "\"TESTING"
+        input = '"TESTING'
         self.assertRaises(ValueError, ujson.decode, input)
 
     def test_decodeStringUntermEscapeSequence(self):
-        input = "\"TESTING\\\""
+        input = '"TESTING\\"'
         self.assertRaises(ValueError, ujson.decode, input)
 
     def test_decodeStringBadEscape(self):
-        input = "\"TESTING\\\""
+        input = '"TESTING\\"'
         self.assertRaises(ValueError, ujson.decode, input)
 
     def test_decodeTrueBroken(self):
@@ -418,7 +420,7 @@ class UltraJSONTests(unittest.TestCase):
             self.assertRaises(ValueError, ujson.decode, input)
 
     def test_decodeBrokenListLeakTest(self):
-        input = '[[[true'
+        input = "[[[true"
         for x in range(1000):
             self.assertRaises(ValueError, ujson.decode, input)
 
@@ -427,11 +429,11 @@ class UltraJSONTests(unittest.TestCase):
         self.assertRaises(ValueError, ujson.decode, input)
 
     def test_decodeDictWithNoColonOrValue(self):
-        input = "{{{{\"key\"}}}}"
+        input = '{{{{"key"}}}}'
         self.assertRaises(ValueError, ujson.decode, input)
 
     def test_decodeDictWithNoValue(self):
-        input = "{{{{\"key\":}}}}"
+        input = '{{{{"key":}}}}'
         self.assertRaises(ValueError, ujson.decode, input)
 
     def test_decodeNumericIntPos(self):
@@ -462,12 +464,18 @@ class UltraJSONTests(unittest.TestCase):
         self.assertEqual('"  \\u0000\\r\\n "', ujson.dumps("  \u0000\r\n "))
 
     def test_decodeNullCharacter(self):
-        input = "\"31337 \\u0000 31337\""
+        input = '"31337 \\u0000 31337"'
         self.assertEqual(ujson.decode(input), json.loads(input))
 
     def test_encodeListLongConversion(self):
-        input = [9223372036854775807, 9223372036854775807, 9223372036854775807,
-                 9223372036854775807, 9223372036854775807, 9223372036854775807]
+        input = [
+            9223372036854775807,
+            9223372036854775807,
+            9223372036854775807,
+            9223372036854775807,
+            9223372036854775807,
+            9223372036854775807,
+        ]
         output = ujson.encode(input)
         self.assertEqual(input, json.loads(output))
         self.assertEqual(input, ujson.decode(output))
@@ -535,14 +543,14 @@ class UltraJSONTests(unittest.TestCase):
         self.assertEqual(output, json.loads(input))
 
     def test_dumpToFile(self):
-        f = six.StringIO()
+        f = StringIO()
         ujson.dump([1, 2, 3], f)
         self.assertEqual("[1,2,3]", f.getvalue())
 
     def test_dumpToFileLikeObject(self):
         class filelike:
             def __init__(self):
-                self.bytes = ''
+                self.bytes = ""
 
             def write(self, bytes):
                 self.bytes += bytes
@@ -552,10 +560,10 @@ class UltraJSONTests(unittest.TestCase):
         self.assertEqual("[1,2,3]", f.bytes)
 
     def test_dumpFileArgsError(self):
-        self.assertRaises(TypeError, ujson.dump, [], '')
+        self.assertRaises(TypeError, ujson.dump, [], "")
 
     def test_loadFile(self):
-        f = six.StringIO("[1,2,3,4]")
+        f = StringIO("[1,2,3,4]")
         self.assertEqual([1, 2, 3, 4], ujson.load(f))
 
     def test_loadFileLikeObject(self):
@@ -577,35 +585,28 @@ class UltraJSONTests(unittest.TestCase):
         self.assertRaises(OverflowError, ujson.encode, 12839128391289382193812939)
 
     def test_decodeNumberWith32bitSignBit(self):
-        #Test that numbers that fit within 32 bits but would have the
+        # Test that numbers that fit within 32 bits but would have the
         # sign bit set (2**31 <= x < 2**32) are decoded properly.
         docs = (
             '{"id": 3590016419}',
-            '{"id": %s}' % 2**31,
-            '{"id": %s}' % 2**32,
-            '{"id": %s}' % ((2**32)-1),
+            '{"id": %s}' % 2 ** 31,
+            '{"id": %s}' % 2 ** 32,
+            '{"id": %s}' % ((2 ** 32) - 1),
         )
-        results = (3590016419, 2**31, 2**32, 2**32-1)
+        results = (3590016419, 2 ** 31, 2 ** 32, 2 ** 32 - 1)
         for doc, result in zip(docs, results):
-            self.assertEqual(ujson.decode(doc)['id'], result)
+            self.assertEqual(ujson.decode(doc)["id"], result)
 
     def test_encodeBigEscape(self):
         for x in range(10):
-            if six.PY3:
-                base = '\u00e5'.encode('utf-8')
-            else:
-                base = "\xc3\xa5"
+            base = "\u00e5".encode("utf-8")
             input = base * 1024 * 1024 * 2
             ujson.encode(input)
 
     def test_decodeBigEscape(self):
         for x in range(10):
-            if six.PY3:
-                base = '\u00e5'.encode('utf-8')
-                quote = "\"".encode()
-            else:
-                base = "\xc3\xa5"
-                quote = "\""
+            base = "\u00e5".encode("utf-8")
+            quote = '"'.encode()
             input = quote + (base * 1024 * 1024 * 2) + quote
             ujson.decode(input)
 
@@ -615,8 +616,9 @@ class UltraJSONTests(unittest.TestCase):
         class DictTest:
             def toDict(self):
                 return d
+
             def __json__(self):
-                return '"json defined"' # Fallback and shouldn't be called.
+                return '"json defined"'  # Fallback and shouldn't be called.
 
         o = DictTest()
         output = ujson.encode(o)
@@ -626,50 +628,54 @@ class UltraJSONTests(unittest.TestCase):
     def test_object_with_json(self):
         # If __json__ returns a string, then that string
         # will be used as a raw JSON snippet in the object.
-        output_text = 'this is the correct output'
+        output_text = "this is the correct output"
+
         class JSONTest:
             def __json__(self):
                 return '"' + output_text + '"'
 
-        d = {u'key': JSONTest()}
+        d = {u"key": JSONTest()}
         output = ujson.encode(d)
         dec = ujson.decode(output)
-        self.assertEqual(dec, {u'key': output_text})
+        self.assertEqual(dec, {u"key": output_text})
 
     def test_object_with_json_unicode(self):
         # If __json__ returns a string, then that string
         # will be used as a raw JSON snippet in the object.
-        output_text = u'this is the correct output'
+        output_text = u"this is the correct output"
+
         class JSONTest:
             def __json__(self):
                 return u'"' + output_text + u'"'
 
-        d = {u'key': JSONTest()}
+        d = {u"key": JSONTest()}
         output = ujson.encode(d)
         dec = ujson.decode(output)
-        self.assertEqual(dec, {u'key': output_text})
+        self.assertEqual(dec, {u"key": output_text})
 
     def test_object_with_complex_json(self):
         # If __json__ returns a string, then that string
         # will be used as a raw JSON snippet in the object.
-        obj = {u'foo': [u'bar', u'baz']}
+        obj = {u"foo": [u"bar", u"baz"]}
+
         class JSONTest:
             def __json__(self):
                 return ujson.encode(obj)
 
-        d = {u'key': JSONTest()}
+        d = {u"key": JSONTest()}
         output = ujson.encode(d)
         dec = ujson.decode(output)
-        self.assertEqual(dec, {u'key': obj})
+        self.assertEqual(dec, {u"key": obj})
 
     def test_object_with_json_type_error(self):
         # __json__ must return a string, otherwise it should raise an error.
         for return_value in (None, 1234, 12.34, True, {}):
+
             class JSONTest:
                 def __json__(self):
                     return return_value
 
-            d = {u'key': JSONTest()}
+            d = {u"key": JSONTest()}
             self.assertRaises(TypeError, ujson.encode, d)
 
     def test_object_with_json_attribute_error(self):
@@ -678,7 +684,7 @@ class UltraJSONTests(unittest.TestCase):
             def __json__(self):
                 raise AttributeError
 
-        d = {u'key': JSONTest()}
+        d = {u"key": JSONTest()}
         self.assertRaises(AttributeError, ujson.encode, d)
 
     def test_decodeArrayTrailingCommaFail(self):
@@ -702,11 +708,6 @@ class UltraJSONTests(unittest.TestCase):
         obj = ujson.decode(input)
         self.assertEqual([], obj)
 
-    def test_decodeArrayDict(self):
-        input = "{}"
-        obj = ujson.decode(input)
-        self.assertEqual({}, obj)
-
     def test_decodeArrayOneItem(self):
         input = "[31337]"
         ujson.decode(input)
@@ -748,7 +749,7 @@ class UltraJSONTests(unittest.TestCase):
         self.assertRaises(ValueError, ujson.decode, input)
 
     def test_decodeArrayWithBigInt(self):
-        input = '[18446744073709551616]'
+        input = "[18446744073709551616]"
         self.assertRaises(ValueError, ujson.decode, input)
 
     def test_decodeFloatingPointAdditionalTests(self):
@@ -758,7 +759,7 @@ class UltraJSONTests(unittest.TestCase):
         self.assertEqual(-1.4567893, ujson.loads("-1.4567893"))
         self.assertEqual(-1.567893, ujson.loads("-1.567893"))
         self.assertEqual(-1.67893, ujson.loads("-1.67893"))
-        self.assertEqual(-1.7893, ujson.loads("-1.7893"))
+        self.assertEqual(-1.7894, ujson.loads("-1.7894"))
         self.assertEqual(-1.893, ujson.loads("-1.893"))
         self.assertEqual(-1.3, ujson.loads("-1.3"))
 
@@ -768,7 +769,7 @@ class UltraJSONTests(unittest.TestCase):
         self.assertEqual(1.4567893, ujson.loads("1.4567893"))
         self.assertEqual(1.567893, ujson.loads("1.567893"))
         self.assertEqual(1.67893, ujson.loads("1.67893"))
-        self.assertEqual(1.7893, ujson.loads("1.7893"))
+        self.assertEqual(1.7894, ujson.loads("1.7894"))
         self.assertEqual(1.893, ujson.loads("1.893"))
         self.assertEqual(1.3, ujson.loads("1.3"))
 
@@ -803,7 +804,6 @@ class UltraJSONTests(unittest.TestCase):
     def test_WriteArrayOfSymbolsFromTuple(self):
         self.assertEqual("[true,false,null]", ujson.dumps((True, False, None)))
 
-    @unittest.skipIf(not six.PY3, "Only raises on Python 3")
     def test_encodingInvalidUnicodeCharacter(self):
         s = "\udc7f"
         self.assertRaises(UnicodeEncodeError, ujson.dumps, s)
@@ -813,9 +813,9 @@ class UltraJSONTests(unittest.TestCase):
         sortedKeys = ujson.dumps(data, sort_keys=True)
         self.assertEqual(sortedKeys, '{"a":1,"b":1,"c":1,"d":1,"e":1,"f":1}')
 
-    @unittest.skipIf(not hasattr(sys, 'getrefcount') == True, reason="test requires sys.refcount")
     def test_does_not_leak_dictionary_values(self):
         import gc
+
         gc.collect()
         value = ["abc"]
         data = {"1": value}
@@ -823,9 +823,9 @@ class UltraJSONTests(unittest.TestCase):
         ujson.dumps(data)
         self.assertEqual(ref_count, sys.getrefcount(value))
 
-    @unittest.skipIf(not hasattr(sys, 'getrefcount') == True, reason="test requires sys.refcount")
     def test_does_not_leak_dictionary_keys(self):
         import gc
+
         gc.collect()
         key1 = "1"
         key2 = "1"
@@ -838,9 +838,9 @@ class UltraJSONTests(unittest.TestCase):
         self.assertEqual(ref_count1, sys.getrefcount(key1))
         self.assertEqual(ref_count2, sys.getrefcount(key2))
 
-    @unittest.skipIf(not hasattr(sys, 'getrefcount') == True, reason="test requires sys.refcount")
     def test_does_not_leak_dictionary_string_key(self):
         import gc
+
         gc.collect()
         key1 = "1"
         value1 = 1
@@ -849,9 +849,9 @@ class UltraJSONTests(unittest.TestCase):
         ujson.dumps(data)
         self.assertEqual(ref_count1, sys.getrefcount(key1))
 
-    @unittest.skipIf(not hasattr(sys, 'getrefcount') == True, reason="test requires sys.refcount")
     def test_does_not_leak_dictionary_tuple_key(self):
         import gc
+
         gc.collect()
         key1 = ("a",)
         value1 = 1
@@ -860,9 +860,9 @@ class UltraJSONTests(unittest.TestCase):
         ujson.dumps(data)
         self.assertEqual(ref_count1, sys.getrefcount(key1))
 
-    @unittest.skipIf(not hasattr(sys, 'getrefcount') == True, reason="test requires sys.refcount")
     def test_does_not_leak_dictionary_bytes_key(self):
         import gc
+
         gc.collect()
         key1 = b"1"
         value1 = 1
@@ -871,9 +871,9 @@ class UltraJSONTests(unittest.TestCase):
         ujson.dumps(data)
         self.assertEqual(ref_count1, sys.getrefcount(key1))
 
-    @unittest.skipIf(not hasattr(sys, 'getrefcount') == True, reason="test requires sys.refcount")
     def test_does_not_leak_dictionary_None_key(self):
         import gc
+
         gc.collect()
         key1 = None
         value1 = 1
